@@ -10,14 +10,20 @@ from pathlib import Path
 from github import Github
 from github.GithubException import GithubException
 
-from .funcs import get_token
+from .funcs import get_github_tok_fp
+from .funcs import get_github_usr_tok_fr_js_file
+from .funcs import RGet
 from .repo import Repo
 
 
-@dataclass
-class RRetFpsPyGithubRepoObj :
-    fps: list
-    pygithub_repo_obj: object
+def get_token(github_usr = None) :
+    fp = get_github_tok_fp()
+    if fp :
+        o = get_github_usr_tok_fr_js_file(fp , usr = github_usr)
+        return RGet(usr = o.usr , tok = o.tok)
+
+    tok = input('enter github access token:')
+    return tok
 
 
 def ret_usr_repo_from_repo_url(repo_url) :
@@ -26,10 +32,10 @@ def ret_usr_repo_from_repo_url(repo_url) :
     return rp.user_repo
 
 
-def ret_pygithub_repo_obj(usr_repo , tok = None) :
+def ret_pygithub_repo_obj(usr_repo , tok = None , github_usr = None) :
     """ Return a PyGitHub repo object. """
     if not tok :
-        tok = get_token()
+        tok = get_token(github_usr = github_usr)
     g = Github(tok)
     return g.get_repo(usr_repo)
 
@@ -116,7 +122,9 @@ def add_overwrite_a_file_2_repo(fp , repo_url , msg = None , branch = 'main') :
 def _find_new_files_fr_dir_not_in_repo_by_suf(dirpath ,
                                               file_suf ,
                                               pygithub_repo_obj) :
-    fps = list(Path(dirpath).glob(f'*{file_suf}'))
+    pth_ptrn = f'*{file_suf}'
+
+    fps = list(Path(dirpath).glob(pth_ptrn))
     print(f'{file_suf} files count in {dirpath}:  {len(fps)}')
 
     rp = pygithub_repo_obj
@@ -125,7 +133,7 @@ def _find_new_files_fr_dir_not_in_repo_by_suf(dirpath ,
     print(f'all files count in {rp.full_name}:  {len(ofns)}')
 
     ofns = [Path(x.path) for x in ofns]
-    ofns = [x.name for x in ofns if x.suffix == f'{file_suf}']
+    ofns = [x.name for x in ofns if x.match(pth_ptrn)]
     print(f'{file_suf} files count in {rp.full_name}:  {len(ofns)}')
 
     fns = [x.name for x in fps]
@@ -153,7 +161,7 @@ def add_overwrite_files_by_suf_fr_dir_2_repo(dirpath ,
     fu = _add_overwrite_a_file_2_repo
 
     if overwrite :
-        fps = list(_dir.glob(f'*.{file_suf}'))
+        fps = list(_dir.glob(f'*{file_suf}'))
         _ = [fu(x , rp) for x in fps]
     else :
         fu1 = _find_new_files_fr_dir_not_in_repo_by_suf
@@ -162,17 +170,24 @@ def add_overwrite_files_by_suf_fr_dir_2_repo(dirpath ,
         _ = [fu(x , rp) for x in fps]
 
 
-def ret_fps_pygithub_repo_inst_for_multiprocess(dirpath ,
-                                                file_suf ,
-                                                repo_url ,
-                                                overwrite = False) :
+@dataclass
+class RRetFpsPyGithubRepoObj :
+    fps: list
+    pygithub_repo_obj: object
+
+
+def ret_fps_and_pygithub_repo_obj(dirpath ,
+                                  file_suf ,
+                                  repo_url ,
+                                  github_usr = None ,
+                                  overwrite = False) :
     ur = ret_usr_repo_from_repo_url(repo_url)
-    rp = ret_pygithub_repo_obj(ur)
+    rp = ret_pygithub_repo_obj(ur , github_usr = github_usr)
 
     _dir = Path(dirpath)
 
     if overwrite :
-        fps = list(_dir.glob(f'*.{file_suf}'))
+        fps = list(_dir.glob(f'*{file_suf}'))
     else :
         fu1 = _find_new_files_fr_dir_not_in_repo_by_suf
         fns = fu1(dirpath , file_suf , rp)
@@ -182,15 +197,17 @@ def ret_fps_pygithub_repo_inst_for_multiprocess(dirpath ,
     return ro(fps = fps , pygithub_repo_obj = rp)
 
 
-def _upload_files_from_dir_2_repo_mp(dirpath ,
-                                     file_suf ,
-                                     repo_url ,
-                                     overwrite = False ,
-                                     n_jobs = 50) :
-    fu = ret_fps_pygithub_repo_inst_for_multiprocess
+def upload_files_by_suf_from_dir_2_repo_mp(dirpath ,
+                                           file_suf ,
+                                           repo_url ,
+                                           github_usr = None ,
+                                           overwrite = False ,
+                                           n_jobs = 50) :
+    fu = ret_fps_and_pygithub_repo_obj
     ou = fu(dirpath = dirpath ,
             file_suf = file_suf ,
             repo_url = repo_url ,
+            github_usr = github_usr ,
             overwrite = overwrite)
 
     fps = ou.fps
@@ -208,18 +225,20 @@ def _upload_files_from_dir_2_repo_mp(dirpath ,
     return len(fps)
 
 
-def upload_files_from_dir_2_repo_mp(dirpath ,
-                                    file_suf ,
-                                    repo_url ,
-                                    overwrite = False ,
-                                    n_jobs = 50) :
-    fu = _upload_files_from_dir_2_repo_mp
+def persistently_upload_files_from_dir_2_repo_mp(dirpath ,
+                                                 file_suf ,
+                                                 repo_url ,
+                                                 github_usr = None ,
+                                                 overwrite = False ,
+                                                 n_jobs = 50) :
+    fu = upload_files_by_suf_from_dir_2_repo_mp
     while True :
 
         try :
             n = fu(dirpath = dirpath ,
                    file_suf = file_suf ,
                    repo_url = repo_url ,
+                   github_usr = github_usr ,
                    overwrite = overwrite ,
                    n_jobs = n_jobs)
             if n == 0 :
